# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.comprobante_electrnico_de_pago__cep_api import ComprobanteElectrnicoDePagoCEPApi  # noqa: E501
from wire4_client.rest import ApiException


class TestComprobanteElectrnicoDePagoCEPApi(unittest.TestCase):
    """ComprobanteElectrnicoDePagoCEPApi unit test stubs"""

    def setUp(self):
        self.api = api.comprobante_electrnico_de_pago__cep_api.ComprobanteElectrnicoDePagoCEPApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_obtain_transaction_cep_using_post(self):
        """Test case for obtain_transaction_cep_using_post

        Consulta de CEP  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
