# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MessageWebHook(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'created': 'datetime',
        'data': 'object',
        'id': 'str',
        'livemode': 'bool',
        'object': 'str',
        'pending_webhooks': 'int',
        'request': 'str',
        'type': 'str'
    }

    attribute_map = {
        'api_version': 'api_version',
        'created': 'created',
        'data': 'data',
        'id': 'id',
        'livemode': 'livemode',
        'object': 'object',
        'pending_webhooks': 'pending_webhooks',
        'request': 'request',
        'type': 'type'
    }

    def __init__(self, api_version=None, created=None, data=None, id=None, livemode=None, object=None, pending_webhooks=None, request=None, type=None):  # noqa: E501
        """MessageWebHook - a model defined in Swagger"""  # noqa: E501
        self._api_version = None
        self._created = None
        self._data = None
        self._id = None
        self._livemode = None
        self._object = None
        self._pending_webhooks = None
        self._request = None
        self._type = None
        self.discriminator = None
        if api_version is not None:
            self.api_version = api_version
        if created is not None:
            self.created = created
        if data is not None:
            self.data = data
        if id is not None:
            self.id = id
        if livemode is not None:
            self.livemode = livemode
        if object is not None:
            self.object = object
        if pending_webhooks is not None:
            self.pending_webhooks = pending_webhooks
        if request is not None:
            self.request = request
        if type is not None:
            self.type = type

    @property
    def api_version(self):
        """Gets the api_version of this MessageWebHook.  # noqa: E501

        Es la versión de esta API.  # noqa: E501

        :return: The api_version of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this MessageWebHook.

        Es la versión de esta API.  # noqa: E501

        :param api_version: The api_version of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def created(self):
        """Gets the created of this MessageWebHook.  # noqa: E501

        Fecha de creación del mensaje.  # noqa: E501

        :return: The created of this MessageWebHook.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this MessageWebHook.

        Fecha de creación del mensaje.  # noqa: E501

        :param created: The created of this MessageWebHook.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def data(self):
        """Gets the data of this MessageWebHook.  # noqa: E501

        Es el objeto que contiene la información del evento.  # noqa: E501

        :return: The data of this MessageWebHook.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this MessageWebHook.

        Es el objeto que contiene la información del evento.  # noqa: E501

        :param data: The data of this MessageWebHook.  # noqa: E501
        :type: object
        """

        self._data = data

    @property
    def id(self):
        """Gets the id of this MessageWebHook.  # noqa: E501

        Es el identificador del mensaje.  # noqa: E501

        :return: The id of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MessageWebHook.

        Es el identificador del mensaje.  # noqa: E501

        :param id: The id of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def livemode(self):
        """Gets the livemode of this MessageWebHook.  # noqa: E501

        Indica si proviene de un entorno productivo.  # noqa: E501

        :return: The livemode of this MessageWebHook.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this MessageWebHook.

        Indica si proviene de un entorno productivo.  # noqa: E501

        :param livemode: The livemode of this MessageWebHook.  # noqa: E501
        :type: bool
        """

        self._livemode = livemode

    @property
    def object(self):
        """Gets the object of this MessageWebHook.  # noqa: E501

        Tipo de objeto  que contiene el mensaje en el atributo 'data'. Los posibles valores son:  <ul><li>subscription</li>, <li>beneficiary</li>, <li>spei_outgoing</li>, <li>spei_incoming</li>, <li>spid_outgoing</li>, <li>request_outgoing</li><ul>   # noqa: E501

        :return: The object of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this MessageWebHook.

        Tipo de objeto  que contiene el mensaje en el atributo 'data'. Los posibles valores son:  <ul><li>subscription</li>, <li>beneficiary</li>, <li>spei_outgoing</li>, <li>spei_incoming</li>, <li>spid_outgoing</li>, <li>request_outgoing</li><ul>   # noqa: E501

        :param object: The object of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def pending_webhooks(self):
        """Gets the pending_webhooks of this MessageWebHook.  # noqa: E501

        Es el número de mensajes pendientes de enviar.  # noqa: E501

        :return: The pending_webhooks of this MessageWebHook.  # noqa: E501
        :rtype: int
        """
        return self._pending_webhooks

    @pending_webhooks.setter
    def pending_webhooks(self, pending_webhooks):
        """Sets the pending_webhooks of this MessageWebHook.

        Es el número de mensajes pendientes de enviar.  # noqa: E501

        :param pending_webhooks: The pending_webhooks of this MessageWebHook.  # noqa: E501
        :type: int
        """

        self._pending_webhooks = pending_webhooks

    @property
    def request(self):
        """Gets the request of this MessageWebHook.  # noqa: E501

        Es el identificador del recurso relacionado.  # noqa: E501

        :return: The request of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this MessageWebHook.

        Es el identificador del recurso relacionado.  # noqa: E501

        :param request: The request of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._request = request

    @property
    def type(self):
        """Gets the type of this MessageWebHook.  # noqa: E501

        El tipo evento que se está enviando en la notificación.  # noqa: E501

        :return: The type of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MessageWebHook.

        El tipo evento que se está enviando en la notificación.  # noqa: E501

        :param type: The type of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageWebHook, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageWebHook):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
