# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PaymentCODI(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'description': 'str',
        'error_message': 'str',
        'id': 'str',
        'operation_date': 'datetime',
        'status': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'description': 'description',
        'error_message': 'error_message',
        'id': 'id',
        'operation_date': 'operation_date',
        'status': 'status'
    }

    def __init__(self, amount=None, description=None, error_message=None, id=None, operation_date=None, status=None):  # noqa: E501
        """PaymentCODI - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._description = None
        self._error_message = None
        self._id = None
        self._operation_date = None
        self._status = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if description is not None:
            self.description = description
        if error_message is not None:
            self.error_message = error_message
        if id is not None:
            self.id = id
        if operation_date is not None:
            self.operation_date = operation_date
        if status is not None:
            self.status = status

    @property
    def amount(self):
        """Gets the amount of this PaymentCODI.  # noqa: E501

        Monto del pago  # noqa: E501

        :return: The amount of this PaymentCODI.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentCODI.

        Monto del pago  # noqa: E501

        :param amount: The amount of this PaymentCODI.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def description(self):
        """Gets the description of this PaymentCODI.  # noqa: E501

        Descripción del pago  # noqa: E501

        :return: The description of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentCODI.

        Descripción del pago  # noqa: E501

        :param description: The description of this PaymentCODI.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def error_message(self):
        """Gets the error_message of this PaymentCODI.  # noqa: E501

        Mensaje de error  # noqa: E501

        :return: The error_message of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this PaymentCODI.

        Mensaje de error  # noqa: E501

        :param error_message: The error_message of this PaymentCODI.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def id(self):
        """Gets the id of this PaymentCODI.  # noqa: E501

        Identificador del pago  # noqa: E501

        :return: The id of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentCODI.

        Identificador del pago  # noqa: E501

        :param id: The id of this PaymentCODI.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def operation_date(self):
        """Gets the operation_date of this PaymentCODI.  # noqa: E501

        Fecha en que se efectuo el pago  # noqa: E501

        :return: The operation_date of this PaymentCODI.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this PaymentCODI.

        Fecha en que se efectuo el pago  # noqa: E501

        :param operation_date: The operation_date of this PaymentCODI.  # noqa: E501
        :type: datetime
        """

        self._operation_date = operation_date

    @property
    def status(self):
        """Gets the status of this PaymentCODI.  # noqa: E501

        Estatus del pago  # noqa: E501

        :return: The status of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PaymentCODI.

        Estatus del pago  # noqa: E501

        :param status: The status of this PaymentCODI.  # noqa: E501
        :type: str
        """
        allowed_values = ["RECEIVED", "COMPLETED", "CANCELLED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentCODI, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentCODI):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
