# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.contacto_api import ContactoApi  # noqa: E501
from wire4_client.rest import ApiException


class TestContactoApi(unittest.TestCase):
    """ContactoApi unit test stubs"""

    def setUp(self):
        self.api = api.contacto_api.ContactoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_send_contact_using_post(self):
        """Test case for send_contact_using_post

        Solicitud de contacto  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
