# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AuthorizedUsers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account': 'str',
        'masked_account': 'str',
        'masked_name': 'str',
        'masked_user_name': 'str',
        'name': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'account': 'account',
        'masked_account': 'masked_account',
        'masked_name': 'masked_name',
        'masked_user_name': 'masked_user_name',
        'name': 'name',
        'user_name': 'user_name'
    }

    def __init__(self, account=None, masked_account=None, masked_name=None, masked_user_name=None, name=None, user_name=None):  # noqa: E501
        """AuthorizedUsers - a model defined in Swagger"""  # noqa: E501
        self._account = None
        self._masked_account = None
        self._masked_name = None
        self._masked_user_name = None
        self._name = None
        self._user_name = None
        self.discriminator = None
        if account is not None:
            self.account = account
        if masked_account is not None:
            self.masked_account = masked_account
        if masked_name is not None:
            self.masked_name = masked_name
        if masked_user_name is not None:
            self.masked_user_name = masked_user_name
        if name is not None:
            self.name = name
        if user_name is not None:
            self.user_name = user_name

    @property
    def account(self):
        """Gets the account of this AuthorizedUsers.  # noqa: E501

        El contrato al cual se le brinda el acceso a la API  # noqa: E501

        :return: The account of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this AuthorizedUsers.

        El contrato al cual se le brinda el acceso a la API  # noqa: E501

        :param account: The account of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._account = account

    @property
    def masked_account(self):
        """Gets the masked_account of this AuthorizedUsers.  # noqa: E501

        El contrato enmascarado al cual se le brinda el acceso a la API  # noqa: E501

        :return: The masked_account of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._masked_account

    @masked_account.setter
    def masked_account(self, masked_account):
        """Sets the masked_account of this AuthorizedUsers.

        El contrato enmascarado al cual se le brinda el acceso a la API  # noqa: E501

        :param masked_account: The masked_account of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._masked_account = masked_account

    @property
    def masked_name(self):
        """Gets the masked_name of this AuthorizedUsers.  # noqa: E501

        El usuario enmascarado que se autorizó  # noqa: E501

        :return: The masked_name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._masked_name

    @masked_name.setter
    def masked_name(self, masked_name):
        """Sets the masked_name of this AuthorizedUsers.

        El usuario enmascarado que se autorizó  # noqa: E501

        :param masked_name: The masked_name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._masked_name = masked_name

    @property
    def masked_user_name(self):
        """Gets the masked_user_name of this AuthorizedUsers.  # noqa: E501

        El nombre enmascarado del usuario de acceso que se autorizó  # noqa: E501

        :return: The masked_user_name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._masked_user_name

    @masked_user_name.setter
    def masked_user_name(self, masked_user_name):
        """Sets the masked_user_name of this AuthorizedUsers.

        El nombre enmascarado del usuario de acceso que se autorizó  # noqa: E501

        :param masked_user_name: The masked_user_name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._masked_user_name = masked_user_name

    @property
    def name(self):
        """Gets the name of this AuthorizedUsers.  # noqa: E501

        El usuario que se autorizó  # noqa: E501

        :return: The name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AuthorizedUsers.

        El usuario que se autorizó  # noqa: E501

        :param name: The name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def user_name(self):
        """Gets the user_name of this AuthorizedUsers.  # noqa: E501

        El usuario de acceso que se autorizó  # noqa: E501

        :return: The user_name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this AuthorizedUsers.

        El usuario de acceso que se autorizó  # noqa: E501

        :param user_name: The user_name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuthorizedUsers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthorizedUsers):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
