# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.depositantes_api import DepositantesApi  # noqa: E501
from wire4_client.rest import ApiException


class TestDepositantesApi(unittest.TestCase):
    """DepositantesApi unit test stubs"""

    def setUp(self):
        self.api = api.depositantes_api.DepositantesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_depositants_using_get(self):
        """Test case for get_depositants_using_get

        Consulta de cuentas de depositantes  # noqa: E501
        """
        pass

    def test_register_depositants_using_post(self):
        """Test case for register_depositants_using_post

        Registra un nuevo depositante  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
