# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.contracts_details_api import ContractsDetailsApi  # noqa: E501
from wire4_client.rest import ApiException


class TestContractsDetailsApi(unittest.TestCase):
    """ContractsDetailsApi unit test stubs"""

    def setUp(self):
        self.api = api.contracts_details_api.ContractsDetailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_authorization(self):
        """Test case for create_authorization

        Devuelve la URL para autorización del usuario Monex  # noqa: E501
        """
        pass

    def test_obtain_authorized_users(self):
        """Test case for obtain_authorized_users

        Obtiene los usuarios autorizados  # noqa: E501
        """
        pass

    def test_obtain_authorized_users_by_contract(self):
        """Test case for obtain_authorized_users_by_contract

        Obtiene los usuarios autorizados por contrato  # noqa: E501
        """
        pass

    def test_obtain_contract_details(self):
        """Test case for obtain_contract_details

        Obtiene los detalles de la empresa del contrato  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
