# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from models.authorization_transaction_group import AuthorizationTransactionGroup  # noqa: E501
from wire4_client.rest import ApiException


class TestAuthorizationTransactionGroup(unittest.TestCase):
    """AuthorizationTransactionGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthorizationTransactionGroup(self):
        """Test AuthorizationTransactionGroup"""
        # FIXME: construct object with mandatory attributes with example values
        # model = wire4_client.models.authorization_transaction_group.AuthorizationTransactionGroup()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
