# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.web_hook_deposit_authorization_request import WebHookDepositAuthorizationRequest  # noqa: F401,E501


class DepositAuthorizationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'webhook': 'WebHookDepositAuthorizationRequest',
        'wh_uuid': 'str'
    }

    attribute_map = {
        'enabled': 'enabled',
        'webhook': 'webhook',
        'wh_uuid': 'wh_uuid'
    }

    def __init__(self, enabled=None, webhook=None, wh_uuid=None):  # noqa: E501
        """DepositAuthorizationRequest - a model defined in Swagger"""  # noqa: E501
        self._enabled = None
        self._webhook = None
        self._wh_uuid = None
        self.discriminator = None
        if enabled is not None:
            self.enabled = enabled
        if webhook is not None:
            self.webhook = webhook
        if wh_uuid is not None:
            self.wh_uuid = wh_uuid

    @property
    def enabled(self):
        """Gets the enabled of this DepositAuthorizationRequest.  # noqa: E501

        Indica sí se aplica la autorización de depósitos.  # noqa: E501

        :return: The enabled of this DepositAuthorizationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DepositAuthorizationRequest.

        Indica sí se aplica la autorización de depósitos.  # noqa: E501

        :param enabled: The enabled of this DepositAuthorizationRequest.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def webhook(self):
        """Gets the webhook of this DepositAuthorizationRequest.  # noqa: E501


        :return: The webhook of this DepositAuthorizationRequest.  # noqa: E501
        :rtype: WebHookDepositAuthorizationRequest
        """
        return self._webhook

    @webhook.setter
    def webhook(self, webhook):
        """Sets the webhook of this DepositAuthorizationRequest.


        :param webhook: The webhook of this DepositAuthorizationRequest.  # noqa: E501
        :type: WebHookDepositAuthorizationRequest
        """

        self._webhook = webhook

    @property
    def wh_uuid(self):
        """Gets the wh_uuid of this DepositAuthorizationRequest.  # noqa: E501

        Identificador del webhook.  # noqa: E501

        :return: The wh_uuid of this DepositAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._wh_uuid

    @wh_uuid.setter
    def wh_uuid(self, wh_uuid):
        """Sets the wh_uuid of this DepositAuthorizationRequest.

        Identificador del webhook.  # noqa: E501

        :param wh_uuid: The wh_uuid of this DepositAuthorizationRequest.  # noqa: E501
        :type: str
        """

        self._wh_uuid = wh_uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DepositAuthorizationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DepositAuthorizationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
