# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.puntos_de_venta_co_di_api import PuntosDeVentaCoDiApi  # noqa: E501
from wire4_client.rest import ApiException


class TestPuntosDeVentaCoDiApi(unittest.TestCase):
    """PuntosDeVentaCoDiApi unit test stubs"""

    def setUp(self):
        self.api = api.puntos_de_venta_co_di_api.PuntosDeVentaCoDiApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_sales_point(self):
        """Test case for create_sales_point

        Registro de punto de venta.  # noqa: E501
        """
        pass

    def test_obtain_sale_points(self):
        """Test case for obtain_sale_points

        Consulta de puntos de venta  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
