# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CepResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_beneficiary': 'str',
        'account_sender': 'str',
        'amount': 'float',
        'available': 'bool',
        'beneficiary_bank_key': 'str',
        'beneficiary_name': 'str',
        'beneficiary_rfc': 'str',
        'cadena_original': 'str',
        'capture_date': 'datetime',
        'certificate_serial_number': 'str',
        'clave_rastreo': 'str',
        'description': 'str',
        'iva': 'float',
        'operation_date': 'datetime',
        'operation_date_cep': 'datetime',
        'reference': 'str',
        'sender_bank_key': 'str',
        'sender_name': 'str',
        'sender_rfc': 'str',
        'signature': 'str',
        'url_zip': 'str'
    }

    attribute_map = {
        'account_beneficiary': 'account_beneficiary',
        'account_sender': 'account_sender',
        'amount': 'amount',
        'available': 'available',
        'beneficiary_bank_key': 'beneficiary_bank_key',
        'beneficiary_name': 'beneficiary_name',
        'beneficiary_rfc': 'beneficiary_rfc',
        'cadena_original': 'cadena_original',
        'capture_date': 'capture_date',
        'certificate_serial_number': 'certificate_serial_number',
        'clave_rastreo': 'clave_rastreo',
        'description': 'description',
        'iva': 'iva',
        'operation_date': 'operation_date',
        'operation_date_cep': 'operation_date_cep',
        'reference': 'reference',
        'sender_bank_key': 'sender_bank_key',
        'sender_name': 'sender_name',
        'sender_rfc': 'sender_rfc',
        'signature': 'signature',
        'url_zip': 'url_zip'
    }

    def __init__(self, account_beneficiary=None, account_sender=None, amount=None, available=None, beneficiary_bank_key=None, beneficiary_name=None, beneficiary_rfc=None, cadena_original=None, capture_date=None, certificate_serial_number=None, clave_rastreo=None, description=None, iva=None, operation_date=None, operation_date_cep=None, reference=None, sender_bank_key=None, sender_name=None, sender_rfc=None, signature=None, url_zip=None):  # noqa: E501
        """CepResponse - a model defined in Swagger"""  # noqa: E501
        self._account_beneficiary = None
        self._account_sender = None
        self._amount = None
        self._available = None
        self._beneficiary_bank_key = None
        self._beneficiary_name = None
        self._beneficiary_rfc = None
        self._cadena_original = None
        self._capture_date = None
        self._certificate_serial_number = None
        self._clave_rastreo = None
        self._description = None
        self._iva = None
        self._operation_date = None
        self._operation_date_cep = None
        self._reference = None
        self._sender_bank_key = None
        self._sender_name = None
        self._sender_rfc = None
        self._signature = None
        self._url_zip = None
        self.discriminator = None
        if account_beneficiary is not None:
            self.account_beneficiary = account_beneficiary
        if account_sender is not None:
            self.account_sender = account_sender
        if amount is not None:
            self.amount = amount
        if available is not None:
            self.available = available
        if beneficiary_bank_key is not None:
            self.beneficiary_bank_key = beneficiary_bank_key
        if beneficiary_name is not None:
            self.beneficiary_name = beneficiary_name
        if beneficiary_rfc is not None:
            self.beneficiary_rfc = beneficiary_rfc
        if cadena_original is not None:
            self.cadena_original = cadena_original
        if capture_date is not None:
            self.capture_date = capture_date
        if certificate_serial_number is not None:
            self.certificate_serial_number = certificate_serial_number
        if clave_rastreo is not None:
            self.clave_rastreo = clave_rastreo
        if description is not None:
            self.description = description
        if iva is not None:
            self.iva = iva
        if operation_date is not None:
            self.operation_date = operation_date
        if operation_date_cep is not None:
            self.operation_date_cep = operation_date_cep
        if reference is not None:
            self.reference = reference
        if sender_bank_key is not None:
            self.sender_bank_key = sender_bank_key
        if sender_name is not None:
            self.sender_name = sender_name
        if sender_rfc is not None:
            self.sender_rfc = sender_rfc
        if signature is not None:
            self.signature = signature
        if url_zip is not None:
            self.url_zip = url_zip

    @property
    def account_beneficiary(self):
        """Gets the account_beneficiary of this CepResponse.  # noqa: E501

        Es la cuenta del beneficiario.  # noqa: E501

        :return: The account_beneficiary of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._account_beneficiary

    @account_beneficiary.setter
    def account_beneficiary(self, account_beneficiary):
        """Sets the account_beneficiary of this CepResponse.

        Es la cuenta del beneficiario.  # noqa: E501

        :param account_beneficiary: The account_beneficiary of this CepResponse.  # noqa: E501
        :type: str
        """

        self._account_beneficiary = account_beneficiary

    @property
    def account_sender(self):
        """Gets the account_sender of this CepResponse.  # noqa: E501

        Es la cuenta del ordenante.  # noqa: E501

        :return: The account_sender of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._account_sender

    @account_sender.setter
    def account_sender(self, account_sender):
        """Sets the account_sender of this CepResponse.

        Es la cuenta del ordenante.  # noqa: E501

        :param account_sender: The account_sender of this CepResponse.  # noqa: E501
        :type: str
        """

        self._account_sender = account_sender

    @property
    def amount(self):
        """Gets the amount of this CepResponse.  # noqa: E501

        Es el monto de la transferencia.  # noqa: E501

        :return: The amount of this CepResponse.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CepResponse.

        Es el monto de la transferencia.  # noqa: E501

        :param amount: The amount of this CepResponse.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def available(self):
        """Gets the available of this CepResponse.  # noqa: E501

        Indica si el CEP se encuentra disponible o no.  # noqa: E501

        :return: The available of this CepResponse.  # noqa: E501
        :rtype: bool
        """
        return self._available

    @available.setter
    def available(self, available):
        """Sets the available of this CepResponse.

        Indica si el CEP se encuentra disponible o no.  # noqa: E501

        :param available: The available of this CepResponse.  # noqa: E501
        :type: bool
        """

        self._available = available

    @property
    def beneficiary_bank_key(self):
        """Gets the beneficiary_bank_key of this CepResponse.  # noqa: E501

        Es la clave del banco beneficiario el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :return: The beneficiary_bank_key of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_bank_key

    @beneficiary_bank_key.setter
    def beneficiary_bank_key(self, beneficiary_bank_key):
        """Sets the beneficiary_bank_key of this CepResponse.

        Es la clave del banco beneficiario el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :param beneficiary_bank_key: The beneficiary_bank_key of this CepResponse.  # noqa: E501
        :type: str
        """

        self._beneficiary_bank_key = beneficiary_bank_key

    @property
    def beneficiary_name(self):
        """Gets the beneficiary_name of this CepResponse.  # noqa: E501

        Nombre del beneficiario.  # noqa: E501

        :return: The beneficiary_name of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_name

    @beneficiary_name.setter
    def beneficiary_name(self, beneficiary_name):
        """Sets the beneficiary_name of this CepResponse.

        Nombre del beneficiario.  # noqa: E501

        :param beneficiary_name: The beneficiary_name of this CepResponse.  # noqa: E501
        :type: str
        """

        self._beneficiary_name = beneficiary_name

    @property
    def beneficiary_rfc(self):
        """Gets the beneficiary_rfc of this CepResponse.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) del beneficiario.  # noqa: E501

        :return: The beneficiary_rfc of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_rfc

    @beneficiary_rfc.setter
    def beneficiary_rfc(self, beneficiary_rfc):
        """Sets the beneficiary_rfc of this CepResponse.

        Es el Registro Federal de Contribuyentes (RFC) del beneficiario.  # noqa: E501

        :param beneficiary_rfc: The beneficiary_rfc of this CepResponse.  # noqa: E501
        :type: str
        """

        self._beneficiary_rfc = beneficiary_rfc

    @property
    def cadena_original(self):
        """Gets the cadena_original of this CepResponse.  # noqa: E501

        Cadena original del CEP.  # noqa: E501

        :return: The cadena_original of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._cadena_original

    @cadena_original.setter
    def cadena_original(self, cadena_original):
        """Sets the cadena_original of this CepResponse.

        Cadena original del CEP.  # noqa: E501

        :param cadena_original: The cadena_original of this CepResponse.  # noqa: E501
        :type: str
        """

        self._cadena_original = cadena_original

    @property
    def capture_date(self):
        """Gets the capture_date of this CepResponse.  # noqa: E501

        Es la fecha de captura de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The capture_date of this CepResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._capture_date

    @capture_date.setter
    def capture_date(self, capture_date):
        """Sets the capture_date of this CepResponse.

        Es la fecha de captura de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param capture_date: The capture_date of this CepResponse.  # noqa: E501
        :type: datetime
        """

        self._capture_date = capture_date

    @property
    def certificate_serial_number(self):
        """Gets the certificate_serial_number of this CepResponse.  # noqa: E501

        Número de serie del certificado.  # noqa: E501

        :return: The certificate_serial_number of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._certificate_serial_number

    @certificate_serial_number.setter
    def certificate_serial_number(self, certificate_serial_number):
        """Sets the certificate_serial_number of this CepResponse.

        Número de serie del certificado.  # noqa: E501

        :param certificate_serial_number: The certificate_serial_number of this CepResponse.  # noqa: E501
        :type: str
        """

        self._certificate_serial_number = certificate_serial_number

    @property
    def clave_rastreo(self):
        """Gets the clave_rastreo of this CepResponse.  # noqa: E501

        Es la clave de rastreo.  # noqa: E501

        :return: The clave_rastreo of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._clave_rastreo

    @clave_rastreo.setter
    def clave_rastreo(self, clave_rastreo):
        """Sets the clave_rastreo of this CepResponse.

        Es la clave de rastreo.  # noqa: E501

        :param clave_rastreo: The clave_rastreo of this CepResponse.  # noqa: E501
        :type: str
        """

        self._clave_rastreo = clave_rastreo

    @property
    def description(self):
        """Gets the description of this CepResponse.  # noqa: E501

        Es la descripción de la transferencia.  # noqa: E501

        :return: The description of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CepResponse.

        Es la descripción de la transferencia.  # noqa: E501

        :param description: The description of this CepResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def iva(self):
        """Gets the iva of this CepResponse.  # noqa: E501

        IVA de la transferencia.  # noqa: E501

        :return: The iva of this CepResponse.  # noqa: E501
        :rtype: float
        """
        return self._iva

    @iva.setter
    def iva(self, iva):
        """Sets the iva of this CepResponse.

        IVA de la transferencia.  # noqa: E501

        :param iva: The iva of this CepResponse.  # noqa: E501
        :type: float
        """

        self._iva = iva

    @property
    def operation_date(self):
        """Gets the operation_date of this CepResponse.  # noqa: E501

        Es la fecha de operación de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The operation_date of this CepResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this CepResponse.

        Es la fecha de operación de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param operation_date: The operation_date of this CepResponse.  # noqa: E501
        :type: datetime
        """

        self._operation_date = operation_date

    @property
    def operation_date_cep(self):
        """Gets the operation_date_cep of this CepResponse.  # noqa: E501

        Es la fecha de abono registrada en el CEP.  Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The operation_date_cep of this CepResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date_cep

    @operation_date_cep.setter
    def operation_date_cep(self, operation_date_cep):
        """Sets the operation_date_cep of this CepResponse.

        Es la fecha de abono registrada en el CEP.  Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param operation_date_cep: The operation_date_cep of this CepResponse.  # noqa: E501
        :type: datetime
        """

        self._operation_date_cep = operation_date_cep

    @property
    def reference(self):
        """Gets the reference of this CepResponse.  # noqa: E501

        Es la referencia numérica de la transferencia.  # noqa: E501

        :return: The reference of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this CepResponse.

        Es la referencia numérica de la transferencia.  # noqa: E501

        :param reference: The reference of this CepResponse.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def sender_bank_key(self):
        """Gets the sender_bank_key of this CepResponse.  # noqa: E501

        Es la clave del banco emisor el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :return: The sender_bank_key of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._sender_bank_key

    @sender_bank_key.setter
    def sender_bank_key(self, sender_bank_key):
        """Sets the sender_bank_key of this CepResponse.

        Es la clave del banco emisor el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :param sender_bank_key: The sender_bank_key of this CepResponse.  # noqa: E501
        :type: str
        """

        self._sender_bank_key = sender_bank_key

    @property
    def sender_name(self):
        """Gets the sender_name of this CepResponse.  # noqa: E501

        Es el nombre del emisor.  # noqa: E501

        :return: The sender_name of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._sender_name

    @sender_name.setter
    def sender_name(self, sender_name):
        """Sets the sender_name of this CepResponse.

        Es el nombre del emisor.  # noqa: E501

        :param sender_name: The sender_name of this CepResponse.  # noqa: E501
        :type: str
        """

        self._sender_name = sender_name

    @property
    def sender_rfc(self):
        """Gets the sender_rfc of this CepResponse.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) del emisor.  # noqa: E501

        :return: The sender_rfc of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._sender_rfc

    @sender_rfc.setter
    def sender_rfc(self, sender_rfc):
        """Sets the sender_rfc of this CepResponse.

        Es el Registro Federal de Contribuyentes (RFC) del emisor.  # noqa: E501

        :param sender_rfc: The sender_rfc of this CepResponse.  # noqa: E501
        :type: str
        """

        self._sender_rfc = sender_rfc

    @property
    def signature(self):
        """Gets the signature of this CepResponse.  # noqa: E501

        Firma del CEP..  # noqa: E501

        :return: The signature of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this CepResponse.

        Firma del CEP..  # noqa: E501

        :param signature: The signature of this CepResponse.  # noqa: E501
        :type: str
        """

        self._signature = signature

    @property
    def url_zip(self):
        """Gets the url_zip of this CepResponse.  # noqa: E501

        La url al archivo zip del CEP, el cual contiene el xml y pdf  # noqa: E501

        :return: The url_zip of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._url_zip

    @url_zip.setter
    def url_zip(self, url_zip):
        """Sets the url_zip of this CepResponse.

        La url al archivo zip del CEP, el cual contiene el xml y pdf  # noqa: E501

        :param url_zip: The url_zip of this CepResponse.  # noqa: E501
        :type: str
        """

        self._url_zip = url_zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CepResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CepResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
