# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Depositant(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alias': 'str',
        'currency_code': 'str',
        'depositant_clabe': 'str',
        'email': 'list[str]',
        'name': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'currency_code': 'currency_code',
        'depositant_clabe': 'depositant_clabe',
        'email': 'email',
        'name': 'name'
    }

    def __init__(self, alias=None, currency_code=None, depositant_clabe=None, email=None, name=None):  # noqa: E501
        """Depositant - a model defined in Swagger"""  # noqa: E501
        self._alias = None
        self._currency_code = None
        self._depositant_clabe = None
        self._email = None
        self._name = None
        self.discriminator = None
        if alias is not None:
            self.alias = alias
        if currency_code is not None:
            self.currency_code = currency_code
        if depositant_clabe is not None:
            self.depositant_clabe = depositant_clabe
        if email is not None:
            self.email = email
        if name is not None:
            self.name = name

    @property
    def alias(self):
        """Gets the alias of this Depositant.  # noqa: E501

        Es el alias del depositante.  # noqa: E501

        :return: The alias of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this Depositant.

        Es el alias del depositante.  # noqa: E501

        :param alias: The alias of this Depositant.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def currency_code(self):
        """Gets the currency_code of this Depositant.  # noqa: E501

        Es el código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos. Sólo se permiten los valores <b>MXP</b> y <b>USD</b>.  # noqa: E501

        :return: The currency_code of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this Depositant.

        Es el código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos. Sólo se permiten los valores <b>MXP</b> y <b>USD</b>.  # noqa: E501

        :param currency_code: The currency_code of this Depositant.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def depositant_clabe(self):
        """Gets the depositant_clabe of this Depositant.  # noqa: E501

        Es la cuenta CLABE (es de 18 dígitos) del depositante.  # noqa: E501

        :return: The depositant_clabe of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._depositant_clabe

    @depositant_clabe.setter
    def depositant_clabe(self, depositant_clabe):
        """Sets the depositant_clabe of this Depositant.

        Es la cuenta CLABE (es de 18 dígitos) del depositante.  # noqa: E501

        :param depositant_clabe: The depositant_clabe of this Depositant.  # noqa: E501
        :type: str
        """

        self._depositant_clabe = depositant_clabe

    @property
    def email(self):
        """Gets the email of this Depositant.  # noqa: E501

        Es la lista de correos electrónicos (emails) del depositante.  # noqa: E501

        :return: The email of this Depositant.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Depositant.

        Es la lista de correos electrónicos (emails) del depositante.  # noqa: E501

        :param email: The email of this Depositant.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def name(self):
        """Gets the name of this Depositant.  # noqa: E501

        Es el nombre del depositante.  # noqa: E501

        :return: The name of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Depositant.

        Es el nombre del depositante.  # noqa: E501

        :param name: The name of this Depositant.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Depositant, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Depositant):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
