# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.message_institution import MessageInstitution  # noqa: F401,E501


class MessagePaymentStatePending(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account': 'str',
        'amount': 'float',
        'beneficiary_account': 'str',
        'beneficiary_bank': 'MessageInstitution',
        'beneficiary_name': 'str',
        'concept': 'str',
        'currency_code': 'str',
        'detention_message': 'str',
        'error_message': 'str',
        'order_id': 'str',
        'payment_order_id': 'int',
        'pending_reason': 'str',
        'reference': 'int',
        'request_id': 'str',
        'status_code': 'str',
        'transaction_id': 'int'
    }

    attribute_map = {
        'account': 'account',
        'amount': 'amount',
        'beneficiary_account': 'beneficiary_account',
        'beneficiary_bank': 'beneficiary_bank',
        'beneficiary_name': 'beneficiary_name',
        'concept': 'concept',
        'currency_code': 'currency_code',
        'detention_message': 'detention_message',
        'error_message': 'error_message',
        'order_id': 'order_id',
        'payment_order_id': 'payment_order_id',
        'pending_reason': 'pending_reason',
        'reference': 'reference',
        'request_id': 'request_id',
        'status_code': 'status_code',
        'transaction_id': 'transaction_id'
    }

    def __init__(self, account=None, amount=None, beneficiary_account=None, beneficiary_bank=None, beneficiary_name=None, concept=None, currency_code=None, detention_message=None, error_message=None, order_id=None, payment_order_id=None, pending_reason=None, reference=None, request_id=None, status_code=None, transaction_id=None):  # noqa: E501
        """MessagePaymentStatePending - a model defined in Swagger"""  # noqa: E501
        self._account = None
        self._amount = None
        self._beneficiary_account = None
        self._beneficiary_bank = None
        self._beneficiary_name = None
        self._concept = None
        self._currency_code = None
        self._detention_message = None
        self._error_message = None
        self._order_id = None
        self._payment_order_id = None
        self._pending_reason = None
        self._reference = None
        self._request_id = None
        self._status_code = None
        self._transaction_id = None
        self.discriminator = None
        if account is not None:
            self.account = account
        if amount is not None:
            self.amount = amount
        if beneficiary_account is not None:
            self.beneficiary_account = beneficiary_account
        if beneficiary_bank is not None:
            self.beneficiary_bank = beneficiary_bank
        if beneficiary_name is not None:
            self.beneficiary_name = beneficiary_name
        if concept is not None:
            self.concept = concept
        if currency_code is not None:
            self.currency_code = currency_code
        if detention_message is not None:
            self.detention_message = detention_message
        if error_message is not None:
            self.error_message = error_message
        if order_id is not None:
            self.order_id = order_id
        if payment_order_id is not None:
            self.payment_order_id = payment_order_id
        if pending_reason is not None:
            self.pending_reason = pending_reason
        if reference is not None:
            self.reference = reference
        if request_id is not None:
            self.request_id = request_id
        if status_code is not None:
            self.status_code = status_code
        if transaction_id is not None:
            self.transaction_id = transaction_id

    @property
    def account(self):
        """Gets the account of this MessagePaymentStatePending.  # noqa: E501

        Es la cuenta del ordenante.  # noqa: E501

        :return: The account of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this MessagePaymentStatePending.

        Es la cuenta del ordenante.  # noqa: E501

        :param account: The account of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._account = account

    @property
    def amount(self):
        """Gets the amount of this MessagePaymentStatePending.  # noqa: E501

        Es el monto de la transferencia.  # noqa: E501

        :return: The amount of this MessagePaymentStatePending.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this MessagePaymentStatePending.

        Es el monto de la transferencia.  # noqa: E501

        :param amount: The amount of this MessagePaymentStatePending.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this MessagePaymentStatePending.  # noqa: E501

        Es la cuenta del beneficiario.  # noqa: E501

        :return: The beneficiary_account of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this MessagePaymentStatePending.

        Es la cuenta del beneficiario.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._beneficiary_account = beneficiary_account

    @property
    def beneficiary_bank(self):
        """Gets the beneficiary_bank of this MessagePaymentStatePending.  # noqa: E501


        :return: The beneficiary_bank of this MessagePaymentStatePending.  # noqa: E501
        :rtype: MessageInstitution
        """
        return self._beneficiary_bank

    @beneficiary_bank.setter
    def beneficiary_bank(self, beneficiary_bank):
        """Sets the beneficiary_bank of this MessagePaymentStatePending.


        :param beneficiary_bank: The beneficiary_bank of this MessagePaymentStatePending.  # noqa: E501
        :type: MessageInstitution
        """

        self._beneficiary_bank = beneficiary_bank

    @property
    def beneficiary_name(self):
        """Gets the beneficiary_name of this MessagePaymentStatePending.  # noqa: E501

        Es el nombre del beneficiario.  # noqa: E501

        :return: The beneficiary_name of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_name

    @beneficiary_name.setter
    def beneficiary_name(self, beneficiary_name):
        """Sets the beneficiary_name of this MessagePaymentStatePending.

        Es el nombre del beneficiario.  # noqa: E501

        :param beneficiary_name: The beneficiary_name of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._beneficiary_name = beneficiary_name

    @property
    def concept(self):
        """Gets the concept of this MessagePaymentStatePending.  # noqa: E501

        Es el concepto de la transferencia de salida.  # noqa: E501

        :return: The concept of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._concept

    @concept.setter
    def concept(self, concept):
        """Sets the concept of this MessagePaymentStatePending.

        Es el concepto de la transferencia de salida.  # noqa: E501

        :param concept: The concept of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._concept = concept

    @property
    def currency_code(self):
        """Gets the currency_code of this MessagePaymentStatePending.  # noqa: E501

        Código de divisa de la transferencia de salida. Es en el formato estándar ISO 4217 y es de 3 dígitos. Ejemplo: \"MXN\".  # noqa: E501

        :return: The currency_code of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this MessagePaymentStatePending.

        Código de divisa de la transferencia de salida. Es en el formato estándar ISO 4217 y es de 3 dígitos. Ejemplo: \"MXN\".  # noqa: E501

        :param currency_code: The currency_code of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def detention_message(self):
        """Gets the detention_message of this MessagePaymentStatePending.  # noqa: E501

        Es el Mensaje de detención de Monex, indica la causa por la cuál esta detenida la operación en Monex.  # noqa: E501

        :return: The detention_message of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._detention_message

    @detention_message.setter
    def detention_message(self, detention_message):
        """Sets the detention_message of this MessagePaymentStatePending.

        Es el Mensaje de detención de Monex, indica la causa por la cuál esta detenida la operación en Monex.  # noqa: E501

        :param detention_message: The detention_message of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._detention_message = detention_message

    @property
    def error_message(self):
        """Gets the error_message of this MessagePaymentStatePending.  # noqa: E501

        Es el mensaje de error.  # noqa: E501

        :return: The error_message of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this MessagePaymentStatePending.

        Es el mensaje de error.  # noqa: E501

        :param error_message: The error_message of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def order_id(self):
        """Gets the order_id of this MessagePaymentStatePending.  # noqa: E501

        El identificador de la transferencia de salida.  # noqa: E501

        :return: The order_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this MessagePaymentStatePending.

        El identificador de la transferencia de salida.  # noqa: E501

        :param order_id: The order_id of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment_order_id(self):
        """Gets the payment_order_id of this MessagePaymentStatePending.  # noqa: E501

        Es el identificador de la orden de pago de Monex de la transferencia de salida.  # noqa: E501

        :return: The payment_order_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: int
        """
        return self._payment_order_id

    @payment_order_id.setter
    def payment_order_id(self, payment_order_id):
        """Sets the payment_order_id of this MessagePaymentStatePending.

        Es el identificador de la orden de pago de Monex de la transferencia de salida.  # noqa: E501

        :param payment_order_id: The payment_order_id of this MessagePaymentStatePending.  # noqa: E501
        :type: int
        """

        self._payment_order_id = payment_order_id

    @property
    def pending_reason(self):
        """Gets the pending_reason of this MessagePaymentStatePending.  # noqa: E501

        Es el esaado que identifica la causa por la que la transferencia se ecuentra detenida o  pendiente de procesarse. Los posibles estados son: <ul><li>FI=Fondos Insuficientes</li><li>FM=Firma mancomunada, en espera de ingreso de segundo token de autorización</li><li>DP=Se detecto una transferencia duplicada que esta en wspera de confirmación o de eliminación</li></ul>  # noqa: E501

        :return: The pending_reason of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._pending_reason

    @pending_reason.setter
    def pending_reason(self, pending_reason):
        """Sets the pending_reason of this MessagePaymentStatePending.

        Es el esaado que identifica la causa por la que la transferencia se ecuentra detenida o  pendiente de procesarse. Los posibles estados son: <ul><li>FI=Fondos Insuficientes</li><li>FM=Firma mancomunada, en espera de ingreso de segundo token de autorización</li><li>DP=Se detecto una transferencia duplicada que esta en wspera de confirmación o de eliminación</li></ul>  # noqa: E501

        :param pending_reason: The pending_reason of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._pending_reason = pending_reason

    @property
    def reference(self):
        """Gets the reference of this MessagePaymentStatePending.  # noqa: E501

        Es la referecia de la transferencia.  # noqa: E501

        :return: The reference of this MessagePaymentStatePending.  # noqa: E501
        :rtype: int
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this MessagePaymentStatePending.

        Es la referecia de la transferencia.  # noqa: E501

        :param reference: The reference of this MessagePaymentStatePending.  # noqa: E501
        :type: int
        """

        self._reference = reference

    @property
    def request_id(self):
        """Gets the request_id of this MessagePaymentStatePending.  # noqa: E501

        Es el identificador, en esta API, de la petición de envío de la transferencia de salida.  # noqa: E501

        :return: The request_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this MessagePaymentStatePending.

        Es el identificador, en esta API, de la petición de envío de la transferencia de salida.  # noqa: E501

        :param request_id: The request_id of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def status_code(self):
        """Gets the status_code of this MessagePaymentStatePending.  # noqa: E501

        Es el estado (estatus) de la transferencia de salida. Deberá ser \"PENDING\".  # noqa: E501

        :return: The status_code of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this MessagePaymentStatePending.

        Es el estado (estatus) de la transferencia de salida. Deberá ser \"PENDING\".  # noqa: E501

        :param status_code: The status_code of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._status_code = status_code

    @property
    def transaction_id(self):
        """Gets the transaction_id of this MessagePaymentStatePending.  # noqa: E501

        Es el identificador de Monex de la transferencia de salida, podría no estar presente por lo que Usted debería hacer referencias mediate el paymentOrderID.  # noqa: E501

        :return: The transaction_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: int
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this MessagePaymentStatePending.

        Es el identificador de Monex de la transferencia de salida, podría no estar presente por lo que Usted debería hacer referencias mediate el paymentOrderID.  # noqa: E501

        :param transaction_id: The transaction_id of this MessagePaymentStatePending.  # noqa: E501
        :type: int
        """

        self._transaction_id = transaction_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessagePaymentStatePending, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessagePaymentStatePending):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
