# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.operations import Operations  # noqa: F401,E501


class PagerResponseDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content': 'list[Operations]',
        'number_of_elements': 'int',
        'page': 'int',
        'size': 'int',
        'total_items': 'int',
        'total_pages': 'int'
    }

    attribute_map = {
        'content': 'content',
        'number_of_elements': 'number_of_elements',
        'page': 'page',
        'size': 'size',
        'total_items': 'total_items',
        'total_pages': 'total_pages'
    }

    def __init__(self, content=None, number_of_elements=None, page=None, size=None, total_items=None, total_pages=None):  # noqa: E501
        """PagerResponseDto - a model defined in Swagger"""  # noqa: E501
        self._content = None
        self._number_of_elements = None
        self._page = None
        self._size = None
        self._total_items = None
        self._total_pages = None
        self.discriminator = None
        if content is not None:
            self.content = content
        if number_of_elements is not None:
            self.number_of_elements = number_of_elements
        if page is not None:
            self.page = page
        if size is not None:
            self.size = size
        if total_items is not None:
            self.total_items = total_items
        if total_pages is not None:
            self.total_pages = total_pages

    @property
    def content(self):
        """Gets the content of this PagerResponseDto.  # noqa: E501

        Es el contenido de la respuesta paginada.  # noqa: E501

        :return: The content of this PagerResponseDto.  # noqa: E501
        :rtype: list[Operations]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PagerResponseDto.

        Es el contenido de la respuesta paginada.  # noqa: E501

        :param content: The content of this PagerResponseDto.  # noqa: E501
        :type: list[Operations]
        """

        self._content = content

    @property
    def number_of_elements(self):
        """Gets the number_of_elements of this PagerResponseDto.  # noqa: E501

        Es el número de elementos en la página actual.  # noqa: E501

        :return: The number_of_elements of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._number_of_elements

    @number_of_elements.setter
    def number_of_elements(self, number_of_elements):
        """Sets the number_of_elements of this PagerResponseDto.

        Es el número de elementos en la página actual.  # noqa: E501

        :param number_of_elements: The number_of_elements of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._number_of_elements = number_of_elements

    @property
    def page(self):
        """Gets the page of this PagerResponseDto.  # noqa: E501

        Es el número de página.  # noqa: E501

        :return: The page of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this PagerResponseDto.

        Es el número de página.  # noqa: E501

        :param page: The page of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def size(self):
        """Gets the size of this PagerResponseDto.  # noqa: E501

        Es el tamaño de la página, por ejemplo puede ser 20, que significa que son 20 registros por página.  # noqa: E501

        :return: The size of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PagerResponseDto.

        Es el tamaño de la página, por ejemplo puede ser 20, que significa que son 20 registros por página.  # noqa: E501

        :param size: The size of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def total_items(self):
        """Gets the total_items of this PagerResponseDto.  # noqa: E501

        Es el número total de elementos de la consulta.  # noqa: E501

        :return: The total_items of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._total_items

    @total_items.setter
    def total_items(self, total_items):
        """Sets the total_items of this PagerResponseDto.

        Es el número total de elementos de la consulta.  # noqa: E501

        :param total_items: The total_items of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._total_items = total_items

    @property
    def total_pages(self):
        """Gets the total_pages of this PagerResponseDto.  # noqa: E501

        Es el número total de paginas.  # noqa: E501

        :return: The total_pages of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PagerResponseDto.

        Es el número total de paginas.  # noqa: E501

        :param total_pages: The total_pages of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PagerResponseDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PagerResponseDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
