# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SalesPointRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_ip': 'str',
        'account': 'str',
        'name': 'str',
        'notifications_url': 'str'
    }

    attribute_map = {
        'access_ip': 'access_ip',
        'account': 'account',
        'name': 'name',
        'notifications_url': 'notifications_url'
    }

    def __init__(self, access_ip=None, account=None, name=None, notifications_url=None):  # noqa: E501
        """SalesPointRequest - a model defined in Swagger"""  # noqa: E501
        self._access_ip = None
        self._account = None
        self._name = None
        self._notifications_url = None
        self.discriminator = None
        self.access_ip = access_ip
        self.account = account
        self.name = name
        self.notifications_url = notifications_url

    @property
    def access_ip(self):
        """Gets the access_ip of this SalesPointRequest.  # noqa: E501

        Es la dirección IP desde donde se recibirán las peticiones de este punto de venta  # noqa: E501

        :return: The access_ip of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._access_ip

    @access_ip.setter
    def access_ip(self, access_ip):
        """Sets the access_ip of this SalesPointRequest.

        Es la dirección IP desde donde se recibirán las peticiones de este punto de venta  # noqa: E501

        :param access_ip: The access_ip of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if access_ip is None:
            raise ValueError("Invalid value for `access_ip`, must not be `None`")  # noqa: E501

        self._access_ip = access_ip

    @property
    def account(self):
        """Gets the account of this SalesPointRequest.  # noqa: E501

        Es el número de cuenta CLABE donde se realizará el deposito del cobro CODI®.  # noqa: E501

        :return: The account of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this SalesPointRequest.

        Es el número de cuenta CLABE donde se realizará el deposito del cobro CODI®.  # noqa: E501

        :param account: The account of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if account is None:
            raise ValueError("Invalid value for `account`, must not be `None`")  # noqa: E501

        self._account = account

    @property
    def name(self):
        """Gets the name of this SalesPointRequest.  # noqa: E501

        Es el nombre del punto de venta.  # noqa: E501

        :return: The name of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SalesPointRequest.

        Es el nombre del punto de venta.  # noqa: E501

        :param name: The name of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def notifications_url(self):
        """Gets the notifications_url of this SalesPointRequest.  # noqa: E501

        Es la dirección URL para envíar notificaciones CODI® al punto de venta.  # noqa: E501

        :return: The notifications_url of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._notifications_url

    @notifications_url.setter
    def notifications_url(self, notifications_url):
        """Sets the notifications_url of this SalesPointRequest.

        Es la dirección URL para envíar notificaciones CODI® al punto de venta.  # noqa: E501

        :param notifications_url: The notifications_url of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if notifications_url is None:
            raise ValueError("Invalid value for `notifications_url`, must not be `None`")  # noqa: E501

        self._notifications_url = notifications_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SalesPointRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SalesPointRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
