# coding: utf-8

# flake8: noqa
"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from wire4_client.models.account import Account
from wire4_client.models.account_detail import AccountDetail
from wire4_client.models.account_reassigned import AccountReassigned
from wire4_client.models.account_request import AccountRequest
from wire4_client.models.account_response import AccountResponse
from wire4_client.models.account_spid import AccountSpid
from wire4_client.models.address_company import AddressCompany
from wire4_client.models.amount_request import AmountRequest
from wire4_client.models.authorization_transaction_group import AuthorizationTransactionGroup
from wire4_client.models.authorized_beneficiaries_response import AuthorizedBeneficiariesResponse
from wire4_client.models.authorized_users import AuthorizedUsers
from wire4_client.models.balance import Balance
from wire4_client.models.balance_list_response import BalanceListResponse
from wire4_client.models.beneficiaries_query_register_status import BeneficiariesQueryRegisterStatus
from wire4_client.models.beneficiaries_response import BeneficiariesResponse
from wire4_client.models.beneficiary_institution import BeneficiaryInstitution
from wire4_client.models.billing import Billing
from wire4_client.models.billing_transaction import BillingTransaction
from wire4_client.models.cep_response import CepResponse
from wire4_client.models.cep_search_banxico import CepSearchBanxico
from wire4_client.models.certificate_request import CertificateRequest
from wire4_client.models.codi_code_qr_response_dto import CodiCodeQrResponseDTO
from wire4_client.models.codi_code_request_dto import CodiCodeRequestDTO
from wire4_client.models.codi_operation_response_dto import CodiOperationResponseDTO
from wire4_client.models.codi_operations_filters_request_dto import CodiOperationsFiltersRequestDTO
from wire4_client.models.company_registered import CompanyRegistered
from wire4_client.models.company_requested import CompanyRequested
from wire4_client.models.compay import Compay
from wire4_client.models.configurations_limits import ConfigurationsLimits
from wire4_client.models.contact_request import ContactRequest
from wire4_client.models.contract_detail_request import ContractDetailRequest
from wire4_client.models.contract_detail_response import ContractDetailResponse
from wire4_client.models.deposit import Deposit
from wire4_client.models.deposit_authorization_request import DepositAuthorizationRequest
from wire4_client.models.depositant import Depositant
from wire4_client.models.depositants_register import DepositantsRegister
from wire4_client.models.depositant_count_response import DepositantCountResponse
from wire4_client.models.depositants_response import DepositantsResponse
from wire4_client.models.deposits_authorization_response import DepositsAuthorizationResponse
from wire4_client.models.detailed_error_response import DetailedErrorResponse
from wire4_client.models.error_response import ErrorResponse
from wire4_client.models.get_depositants import GetDepositants
from wire4_client.models.institution import Institution
from wire4_client.models.institutions_list import InstitutionsList
from wire4_client.models.item import Item
from wire4_client.models.message_account_beneficiary import MessageAccountBeneficiary
from wire4_client.models.message_cep import MessageCEP
from wire4_client.models.message_codi_action import MessageCodiAction
from wire4_client.models.message_configurations_limits import MessageConfigurationsLimits
from wire4_client.models.message_deposit_authorization_request import MessageDepositAuthorizationRequest
from wire4_client.models.message_deposit_received import MessageDepositReceived
from wire4_client.models.message_institution import MessageInstitution
from wire4_client.models.message_payment import MessagePayment
from wire4_client.models.message_payment_state_pending import MessagePaymentStatePending
from wire4_client.models.message_request_changed import MessageRequestChanged
from wire4_client.models.message_sales_point import MessageSalesPoint
from wire4_client.models.message_subscription import MessageSubscription
from wire4_client.models.message_user_authorized import MessageUserAuthorized
from wire4_client.models.message_web_hook import MessageWebHook
from wire4_client.models.operations import Operations
from wire4_client.models.pager_response_dto import PagerResponseDto
from wire4_client.models.payment import Payment
from wire4_client.models.payment_codi import PaymentCODI
from wire4_client.models.payment_request_codi_response_dto import PaymentRequestCodiResponseDTO
from wire4_client.models.payments_request_id import PaymentsRequestId
from wire4_client.models.person import Person
from wire4_client.models.pre_enrollment_data import PreEnrollmentData
from wire4_client.models.pre_enrollment_response import PreEnrollmentResponse
from wire4_client.models.pre_monex_authorization import PreMonexAuthorization
from wire4_client.models.relationship import Relationship
from wire4_client.models.relationships_response import RelationshipsResponse
from wire4_client.models.sales_point import SalesPoint
from wire4_client.models.sales_point_found import SalesPointFound
from wire4_client.models.sales_point_request import SalesPointRequest
from wire4_client.models.sales_point_respose import SalesPointRespose
from wire4_client.models.service_banking import ServiceBanking
from wire4_client.models.spid_beneficiaries_response import SpidBeneficiariesResponse
from wire4_client.models.spid_beneficiary_response import SpidBeneficiaryResponse
from wire4_client.models.spid_classification_dto import SpidClassificationDTO
from wire4_client.models.spid_classifications_response_dto import SpidClassificationsResponseDTO
from wire4_client.models.subscription_change_status_request import SubscriptionChangeStatusRequest
from wire4_client.models.token_required_response import TokenRequiredResponse
from wire4_client.models.transaction_error_code import TransactionErrorCode
from wire4_client.models.transaction_outgoing import TransactionOutgoing
from wire4_client.models.transaction_outgoing_spid import TransactionOutgoingSpid
from wire4_client.models.transactions_outgoing_register import TransactionsOutgoingRegister
from wire4_client.models.update_configurations_request_dto import UpdateConfigurationsRequestDTO
from wire4_client.models.urls_redirect import UrlsRedirect
from wire4_client.models.use_service_banking import UseServiceBanking
from wire4_client.models.user_company import UserCompany
from wire4_client.models.web_hook_deposit_authorization_request import WebHookDepositAuthorizationRequest
from wire4_client.models.web_hook_deposit_authorization_response import WebHookDepositAuthorizationResponse
from wire4_client.models.webhook import Webhook
from wire4_client.models.webhook_request import WebhookRequest
from wire4_client.models.webhook_response import WebhookResponse
from wire4_client.models.webhooks_list import WebhooksList
