# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Compay(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commercial_name': 'str',
        'company_id': 'str',
        'name': 'str',
        'rfc': 'str'
    }

    attribute_map = {
        'commercial_name': 'commercial_name',
        'company_id': 'company_id',
        'name': 'name',
        'rfc': 'rfc'
    }

    def __init__(self, commercial_name=None, company_id=None, name=None, rfc=None):  # noqa: E501
        """Compay - a model defined in Swagger"""  # noqa: E501
        self._commercial_name = None
        self._company_id = None
        self._name = None
        self._rfc = None
        self.discriminator = None
        if commercial_name is not None:
            self.commercial_name = commercial_name
        if company_id is not None:
            self.company_id = company_id
        if name is not None:
            self.name = name
        if rfc is not None:
            self.rfc = rfc

    @property
    def commercial_name(self):
        """Gets the commercial_name of this Compay.  # noqa: E501

        Nombre comercial de la empresa  # noqa: E501

        :return: The commercial_name of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._commercial_name

    @commercial_name.setter
    def commercial_name(self, commercial_name):
        """Sets the commercial_name of this Compay.

        Nombre comercial de la empresa  # noqa: E501

        :param commercial_name: The commercial_name of this Compay.  # noqa: E501
        :type: str
        """

        self._commercial_name = commercial_name

    @property
    def company_id(self):
        """Gets the company_id of this Compay.  # noqa: E501

        Identificador de la empresa  # noqa: E501

        :return: The company_id of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this Compay.

        Identificador de la empresa  # noqa: E501

        :param company_id: The company_id of this Compay.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    @property
    def name(self):
        """Gets the name of this Compay.  # noqa: E501

        Nombre de la empresa  # noqa: E501

        :return: The name of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Compay.

        Nombre de la empresa  # noqa: E501

        :param name: The name of this Compay.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rfc(self):
        """Gets the rfc of this Compay.  # noqa: E501

        RFC de la empresa  # noqa: E501

        :return: The rfc of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this Compay.

        RFC de la empresa  # noqa: E501

        :param rfc: The rfc of this Compay.  # noqa: E501
        :type: str
        """

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Compay, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Compay):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
